@@ -28,11 +28,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.21
+Version v3.0.22
 
 =cut
 
-our $VERSION = version->declare("v3.0.21");
+our $VERSION = version->declare("v3.0.22");
 
 =head1 SYNOPSIS
 
@@ -148,7 +148,7 @@ has tail => (
 has encoding => (
 	is     => 'rw',
 	coerce => sub {
-		find_encoding( $_[0] ) if ref( $_[0] ) ne 'OBJECT';
+		find_encoding( $_[0] ) unless ref( $_[0] ) eq 'OBJECT';
 	},
 );
 
@@ -386,27 +386,27 @@ sub parse_license
 
 	#<<<  do not let perltidy touch this (keep long regex on one line)
 	given ($licensetext) {
-		when ( /version ([^ ]+)(?: of the License)?,? or(?: \(at your option\))? version (\d(?:[.-]\d+)*)/ ) {
+		when ( /version (\d(?:\.\d+)*)(?: of the License)?,? or(?: \(at your option\))? version (\d+(?:\.\d+)*)/ ) {
 			$gplver = " (v$1 or v$2)";
 			@spdx_gplver = ( $1, $2 );
 		}
-		when ( /version ([^, ]+?)[.,]? (?:\(?only\)?.? )?(?:of the GNU (Affero )?(Lesser |Library )?General Public License )?(as )?published by the Free Software Foundation/i ) {
+		when ( /version (\d+(?:\.\d+)*)[.,]? (?:\(?only\)?.? )?(?:of the GNU (Affero )?(Lesser |Library )?General Public License )?(as )?published by the Free Software Foundation/i ) {
 			$gplver      = " (v$1)";
 			@spdx_gplver = ($1)
 		}
-		when ( /GNU (?:Affero )?(?:Lesser |Library )?General Public License (?:as )?published by the Free Software Foundation[;,] version ([^, ]+?)[.,]? /i ) {
+		when ( /GNU (?:Affero )?(?:Lesser |Library )?General Public License (?:as )?published by the Free Software Foundation[;,] version (\d+(?:\.\d+)*)[.,]? /i ) {
 			$gplver      = " (v$1)";
 			@spdx_gplver = ($1);
 		}
-		when ( /GNU (?:Affero )?(?:Lesser |Library )?General Public License\s*(?:[(),GPL]+)\s*version (\d+(?:\.\d+)?)[ \.]/i ) {
+		when ( /GNU (?:Affero )?(?:Lesser |Library )?General Public License\s*(?:[(),GPL]+)\s*version (\d+(?:\.\d+)*)[ \.]/i ) {
 			$gplver      = " (v$1)";
 			@spdx_gplver = ($1);
 		}
-		when ( /either version ([^ ]+)(?: of the License)?, or (?:\(at your option\) )?any later version/ ) {
+		when ( /either version (\d+(?:\.\d+)*)(?: of the License)?, or (?:\(at your option\) )?any later version/ ) {
 			$gplver      = " (v$1 or later)";
 			@spdx_gplver = ( $1 . '+' );
 		}
-		when ( /GPL\sas\spublished\sby\sthe\sFree\sSoftware\sFoundation,\sversion\s([\d.]+)/i ) {
+		when ( /GPL\sas\spublished\sby\sthe\sFree\sSoftware\sFoundation,\sversion\s(\d+(?:\.\d+)*)/i ) {
 			$gplver      = " (v$1)";
 			@spdx_gplver = ($1)
 		}
@@ -505,15 +505,15 @@ sub parse_license
 		given ($licensetext) {
 			when ( /All advertising materials mentioning features or use of this software must display the following acknowledge?ment.*This product includes software developed by/i ) {
 				$license = "BSD (4 clause) $license";
-				push @spdx_license, 'BSD-4-Clause';
+				push @spdx_license, 'BSD-4-clause';
 			}
 			when ( /(The name(?:\(s\))? .*? may not|Neither the (names? .*?|authors?) nor the names of( (its|their|other|any))? contributors may) be used to endorse or promote products derived from this software/i ) {
 				$license = "BSD (3 clause) $license";
-				push @spdx_license, 'BSD-3-Clause';
+				push @spdx_license, 'BSD-3-clause';
 			}
 			when ( /Redistributions in binary form must reproduce the above copyright notice/i ) {
 				$license = "BSD (2 clause) $license";
-				push @spdx_license, 'BSD-2-Clause';
+				push @spdx_license, 'BSD-2-clause';
 			}
 			default {
 				$license = "BSD $license";
@@ -524,7 +524,7 @@ sub parse_license
 	elsif ( $licensetext =~ /licen[sc]ebsd(?:-(\d)-clause)?/i ) {
 		if ($1) {
 			$license = "BSD ($1 clause) $license";
-			push @spdx_license, "BSD-$1-Clause";
+			push @spdx_license, "BSD-$1-clause";
 		}
 		else {
 			$license = "BSD $license";
